<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://realestatecrm.io
 * @since      1.0.0
 *
 * @package    Cf7_recrmio
 * @subpackage Cf7_recrmio/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Cf7_recrmio
 * @subpackage Cf7_recrmio/admin
 * @author     Your Name <email@realestatecrm.io>
 */
class Cf7_recrmio_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $cf7_recrmio    The ID of this plugin.
	 */
	private $cf7_recrmio;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;


	public  $LeadWebFormFields = [
		'first_name',
		'last_name',
		'email',
		'phone',
		'addr_country_id',
		'addr_city',
		'description'
	];

	public  $ContactWebFormFields = [
		'country',
		'city',
		'comment'
	];



	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $cf7_recrmio       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($cf7_recrmio, $version)
	{

		$this->cf7_recrmio = $cf7_recrmio;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cf7_recrmio_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cf7_recrmio_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->cf7_recrmio, plugin_dir_url(__FILE__) . 'css/cf7-recrmio-admin.css', array(), $this->version, 'all');
		wp_enqueue_style($this->cf7_recrmio . '-remarsostylecss', plugin_dir_url(__FILE__) . 'assets/css/style.css', array(), $this->version, 'all');
		wp_enqueue_style($this->cf7_recrmio . '-remarsobootstrapcss', plugin_dir_url(__FILE__) . 'assets/bootstrap-4.4.1/css/bootstrap.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cf7_recrmio_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cf7_recrmio_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->cf7_recrmio, plugin_dir_url(__FILE__) . 'js/cf7-recrmio-admin.js', array('jquery'), $this->version, false);
	}


	/**
	 * Check contact for 7 availability
	 *
	 * @since    1.0.0
	 */
	public function checkCf7()
	{
		$class = 'notice notice-error';
		$message = __('Contact form 7 is required for  Contact form 7 + Realestatecrm plugin. ', 'cf7-recrmio');

		printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), esc_html($message));
	}

	public function register_setting_menu()
	{
		add_options_page('Settings', 'Contact form 7 + Realestatecrm', 'manage_options', 'cf7-recrmio',  array($this, 'cf7_recrmio_options_page'));
	}

	public function register_log_menu()
	{
		add_submenu_page('wpcf7', 'Realestatecrm Log', 'Realestatecrm Log',  'manage_options', 'cf7-recrmio-log',  array($this, 'showResponseLog'));
	}



	public function cf7_recrmio_options_page()
	{


		$api_key =  get_option('cf7-recrmio_api_key');
		if (isset($_POST['companyapi'])) {
			if (!$this->validateApiKey($_POST)) {
				$error = 'Invalid API key.';
			} else {
				$success = 'Successfully connected';
			}
			$api_key  = sanitize_key($_POST['companyapi']);
		}
		$is_valid = get_option('cf7-recrmio_is_valid_key');
		require_once plugin_dir_path(__FILE__) . 'partials/cf7-recrmio-admin-setting.php';
	}

	public function validateApiKey($data)
	{
		$api_key =  sanitize_key($data['companyapi']);

		$post_data = [
			'api_key' => $api_key
		];
		$wp_request_headers = array(
			'Content-Type' => 'application/json'
		);
		$url        = CF7_RECRMIO_API . '/webform/key/validate';
		$response = wp_remote_post(
			$url,
			array(
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => $wp_request_headers,
				'body'        => json_encode($post_data),
				'cookies'     => array()
			)
		);
		if (is_wp_error($response)) {
			$error_message = $response->get_error_message();
			update_option('cf7-recrmio_is_valid_key_log', $error_message);
			update_option('cf7-recrmio_is_valid_key', 'no');
			update_option('cf7-recrmio_api_key', '');
			update_option('cf7-recrmio_company_id', '');
			return false;
		}

		$data = json_decode($response['body']);

		if (isset($data->errors) && !empty($data->errors)) {
			update_option('cf7-recrmio_is_valid_key_log', $data->errors->api_key[0]);
			update_option('cf7-recrmio_is_valid_key', 'no');
			update_option('cf7-recrmio_api_key', '');
			update_option('cf7-recrmio_company_id', '');
			return false;
		} else {
			update_option('cf7-recrmio_api_key', $api_key);
			update_option('cf7-recrmio_company_id', $data->data->user->company_id);
			update_option('cf7-recrmio_is_valid_key', 'yes');
			return true;
		}
	}

	public function add_cf7_recrmio_tab($panels)
	{
		$integration_panel = array(
			'title'    => __('Realestatecrm Webform', $this->cf7_recrmio),
			'callback' => array($this, 'cf7_recrmio_webform_integrations')
		);

		$panels["cf7-recrmio-webform-integration"] = $integration_panel;

		return $panels;
	}

	public function cf7_recrmio_webform_integrations($post)
	{
		$api_key =  get_option('cf7-recrmio_api_key');

		$data = [
			'companyapi' => $api_key
		];
		$mail_tags                  = $this->get_form_fields($post);
		$extra_data					= $this->get_extra_fields($data);
		$cf7_recrmio_data			= get_post_meta($post->id(), 'cf7_recrmio_data', true);
		// echo "<pre>";
		// print_r($cf7_recrmio_data);
		// echo "</pre>";
		$cf7_recrmio_first_name     = $post->prop('cf7_recrmio_first_name');
		$cf7_recrmio_enable			= isset( $cf7_recrmio_data["cf7_recrmio_enable"] ) ? $cf7_recrmio_data["cf7_recrmio_enable"] : '';
		$cf7_recrmio_creaet_contact	= isset( $cf7_recrmio_data["cf7_recrmio_creaet_contact"] ) ? $cf7_recrmio_data["cf7_recrmio_creaet_contact"] : '';
?>
		<fieldset>
			<?php do_action('before_base_fields', $post); ?>
			<div class="row realestare-backend-form">
				<div class="col-md-10">
					<div class="row">
						<div class="col-md-6">
							<?php _e('Enable RealEstateCRM.io for this form ?', $this->cf7_recrmio); ?>
						</div>
						<div class="col-md-6">
							<input type="checkbox" id="cf7_recrmio_enable" name="cf7_recrmio_enable" value="on" <?php checked($cf7_recrmio_enable, "on"); ?> />
						</div>
					</div>
					<div class="row">
						<div class="col-md-6">
							<?php _e('Create a contact ?', $this->cf7_recrmio); ?>
						</div>
						<div class="col-md-6">
							<input type="checkbox" id="cf7_recrmio_creaet_contact" name="cf7_recrmio_creaet_contact" value="on" <?php checked($cf7_recrmio_creaet_contact, "on"); ?> />
						</div>
					</div>
				</div>
			</div>
			<fieldset>
				<div class="cf7_row">
					<h2><?php echo esc_html(__('Match Fields', $this->cf7_recrmio)); ?></h2>
					<div class="row">
						<div class="col-md-10">
							<p>
							<div class="row">
								<div class="col-md-6">
									<?php _e('First Name', $this->cf7_recrmio); ?>
								</div>
								<div class="col-md-6">
									<select class="form-control cf7_recrmio_select" name="cf7_recrmio_first_name" id="field">
										<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
										<?php foreach ($mail_tags as $mail_tag) : ?>

											<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_first_name"]) && $cf7_recrmio_data["cf7_recrmio_first_name"] ==  $mail_tag->name) {
																								echo "selected";
																							} ?>><?php echo $mail_tag->name; ?></option>

										<?php endforeach; ?>
									</select>
								</div>
							</div>
							</p>
							<p>
							<div class="row">
								<div class="col-md-6">
									<?php _e('Last Name', $this->cf7_recrmio); ?>
								</div>
								<div class="col-md-6">
									<select class="form-control cf7_recrmio_select" name="cf7_recrmio_last_name" id="field">
										<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
										<?php foreach ($mail_tags as $mail_tag) : ?>

											<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_last_name"]) && $cf7_recrmio_data["cf7_recrmio_last_name"] ==  $mail_tag->name) {
																								echo "selected";
																							} ?>><?php echo $mail_tag->name; ?></option>

										<?php endforeach; ?>
									</select>
								</div>
							</div>
							</p>
							<p>
							<div class="row">
								<div class="col-md-6">
									<?php _e('Email', $this->cf7_recrmio); ?>
								</div>
								<div class="col-md-6">
									<select class="form-control cf7_recrmio_select" name="cf7_recrmio_email" id="field">
										<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
										<?php foreach ($mail_tags as $mail_tag) : ?>

											<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_email"]) && $cf7_recrmio_data["cf7_recrmio_email"] ==  $mail_tag->name) {
																								echo "selected";
																							} ?>><?php echo $mail_tag->name; ?></option>

										<?php endforeach; ?>
									</select>
								</div>
							</div>
							</p>
							<p>
							<div class="row">
								<div class="col-md-6">
									<?php _e('Phone', $this->cf7_recrmio); ?>
								</div>
								<div class="col-md-6">
									<select class="form-control cf7_recrmio_select" name="cf7_recrmio_phone" id="field">
										<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
										<?php foreach ($mail_tags as $mail_tag) : ?>

											<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_phone"]) && $cf7_recrmio_data["cf7_recrmio_phone"] ==  $mail_tag->name) {
																								echo "selected";
																							} ?>><?php echo $mail_tag->name; ?></option>

										<?php endforeach; ?>
									</select>
								</div>
							</div>
							</p>
							<p>
							<div class="row">
								<div class="col-md-6">
									<?php _e('City', $this->cf7_recrmio); ?>
								</div>
								<div class="col-md-6">
									<select class="form-control cf7_recrmio_select" name="cf7_recrmio_city" id="field">
										<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
										<?php foreach ($mail_tags as $mail_tag) : ?>

											<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_city"]) && $cf7_recrmio_data["cf7_recrmio_city"] ==  $mail_tag->name) {
																								echo "selected";
																							} ?>><?php echo $mail_tag->name; ?></option>

										<?php endforeach; ?>
									</select>
								</div>
							</div>
							</p>
							<p>
							<div class="row">
								<div class="col-md-6">
									<?php _e('Description', $this->cf7_recrmio); ?>
								</div>
								<div class="col-md-6">
									<select class="form-control cf7_recrmio_select" name="cf7_recrmio_description" id="field">
										<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
										<?php foreach ($mail_tags as $mail_tag) : ?>

											<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_description"]) && $cf7_recrmio_data["cf7_recrmio_description"] ==  $mail_tag->name) {
																								echo "selected";
																							} ?>><?php echo $mail_tag->name; ?></option>

										<?php endforeach; ?>
									</select>
								</div>
							</div>
							</p>

							


						</div>
					</div>
				</div>
			</fieldset>
			<fieldset>
				<h2><?php echo esc_html(__('Extra Fields', $this->cf7_recrmio)); ?></h2>
				<div class="row">
					<div class="col-md-10">
						<p>
						<div class="row">
							<div class="col-md-6">
								<?php _e('Lead Name', $this->cf7_recrmio); ?>
							</div>
							<div class="col-md-6">
								<select class="form-control cf7_recrmio_select" name="cf7_recrmio_lead_name" id="field">
									<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
									<?php foreach ($mail_tags as $mail_tag) : ?>

										<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_lead_name"]) && $cf7_recrmio_data["cf7_recrmio_lead_name"] ==  $mail_tag->name) {
																							echo "selected";
																						} ?>><?php echo $mail_tag->name; ?></option>

									<?php endforeach; ?>
								</select>
							</div>
						</div>
						</p>

						<p>
						<div class="row">
							<div class="col-md-6">
								<?php _e('Lead Company', $this->cf7_recrmio); ?>
							</div>
							<div class="col-md-6">
								<select class="form-control  cf7_recrmio_select" name="cf7_recrmio_lead_company" id="field">
									<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
									<?php foreach ($mail_tags as $mail_tag) : ?>

										<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_lead_company"]) && $cf7_recrmio_data["cf7_recrmio_lead_company"] ==  $mail_tag->name) {
																							echo "selected";
																						} ?>><?php echo $mail_tag->name; ?></option>

									<?php endforeach; ?>
								</select>
							</div>
						</div>
						</p>
						

						<p>
						<div class="row">
							<div class="col-md-6">
								<?php _e('Lead Source', $this->cf7_recrmio); ?>
							</div>
							<div class="col-md-6">
								<select class="form-control cf7_recrmio_select" name="cf7_recrmio_lead_source" id="field">
									<option value=""> <?php _e('Select Lead Source', $this->cf7_recrmio); ?></option>
									<?php foreach ($extra_data->source->choices	 as $key => $choice) : ?>

										<option value="<?php echo $key; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_lead_source"]) && $cf7_recrmio_data["cf7_recrmio_lead_source"] ==  $key) {
																				echo "selected";
																			} ?>><?php echo $choice; ?></option>

									<?php endforeach; ?>
								</select>
							</div>
						</div>
						</p>

						<p>
						<div class="row">
							<div class="col-md-6">
								<?php _e('Lead Source Description', $this->cf7_recrmio); ?>
							</div>
							<div class="col-md-6">
								<select class="form-control cf7_recrmio_select" name="cf7_recrmio_lead_source_description" id="field">
									<option value=""> <?php _e('Select your CF7 fields', $this->cf7_recrmio); ?></option>
									<?php foreach ($mail_tags as $mail_tag) : ?>

										<option value="<?php echo $mail_tag->name; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_lead_source_description"]) && $cf7_recrmio_data["cf7_recrmio_lead_source_description"] ==  $mail_tag->name) {
																							echo "selected";
																						} ?>><?php echo $mail_tag->name; ?></option>

									<?php endforeach; ?>
								</select>
							</div>
						</div>
						</p>

						<p>
						<div class="row">
							<div class="col-md-6">
								<?php _e('Assigned to', $this->cf7_recrmio); ?>
							</div>
							<div class="col-md-6">
								<select class="form-control cf7_recrmio_select" name="cf7_recrmio_lead_assigned_to" id="field">
									<option value=""> <?php _e('Select Assigned To', $this->cf7_recrmio); ?></option>
									<optgroup label="Users">
										<?php foreach ($extra_data->owned_by->choices->Users	 as $key => $choice) : ?>

											<option value="<?php echo $key; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_lead_assigned_to"]) && $cf7_recrmio_data["cf7_recrmio_lead_assigned_to"] ==  $key) {
																					echo "selected";
																				} ?>><?php echo $choice; ?></option>

										<?php endforeach; ?>
									</optgroup>

									<optgroup label="Group">
										<?php foreach ($extra_data->owned_by->choices->Groups	 as $key => $choice) : ?>

											<option value="<?php echo $key; ?>" <?php if (isset($cf7_recrmio_data["cf7_recrmio_lead_assigned_to"]) && $cf7_recrmio_data["cf7_recrmio_lead_assigned_to"] ==  $key) {
																					echo "selected";
																				} ?>><?php echo $choice; ?></option>

										<?php endforeach; ?>
									</optgroup>
								</select>
							</div>
						</div>
						</p>


					</div>
				</div>
			</fieldset>

			<?php do_action('after_base_fields', $post); ?>

		</fieldset>

	<?php
	}


	/**
	 * Collect the mail tags from the form
	 * @return [type] [description]
	 */
	function get_form_fields($post)
	{
		$tags = apply_filters('qs_cf7_collect_mail_tags', $post->scan_form_tags());

		foreach ((array) $tags as $tag) {
			$type = trim($tag['type'], ' *');
			if (empty($type) || empty($tag['name'])) {
				continue;
			} elseif (!empty($args['include'])) {
				if (!in_array($type, $args['include'])) {
					continue;
				}
			} elseif (!empty($args['exclude'])) {
				if (in_array($type, $args['exclude'])) {
					continue;
				}
			}
			$mailtags[] = $tag;
		}

		return $mailtags;
	}

	/**
	 * Collect extra fields data from API
	 */
	function get_extra_fields($data)
	{
		$api_key =  sanitize_key($data['companyapi']);

		$post_data = [
			'api_key' => $api_key
		];

		$wp_request_headers = array(
			'Content-Type' => 'application/json'
		);

		$url        = CF7_RECRMIO_API . '/webform/extrafields/all';

		$response = wp_remote_post(
			$url,
			array(
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => $wp_request_headers,
				'body'        => json_encode($post_data),
				'cookies'     => array()
			)
		);

		if (is_wp_error($response)) {
			$error_message = $response->get_error_message();
			return false;
		}

		$data = json_decode($response['body']);
	

		if (isset($data->errors) && !empty($data->errors)) {
			return false;
		} else {
			return $data->data;
		}
	}

	public function cf7_recrmio_save_contact_form_details($contact_form)
	{
		$form_id = $contact_form->id();
		$properties['cf7_recrmio_enable']     = isset($_POST["cf7_recrmio_enable"]) ? $_POST["cf7_recrmio_enable"] : '';
		$properties['cf7_recrmio_creaet_contact']     = isset($_POST["cf7_recrmio_creaet_contact"]) ? $_POST["cf7_recrmio_creaet_contact"] : '';
		$properties['cf7_recrmio_first_name']     = isset($_POST["cf7_recrmio_first_name"]) ? $_POST["cf7_recrmio_first_name"] : '';
		$properties['cf7_recrmio_first_name']     = isset($_POST["cf7_recrmio_first_name"]) ? $_POST["cf7_recrmio_first_name"] : '';
		$properties['cf7_recrmio_last_name']     = isset($_POST["cf7_recrmio_last_name"]) ? $_POST["cf7_recrmio_last_name"] : '';
		$properties['cf7_recrmio_email']     = isset($_POST["cf7_recrmio_email"]) ? $_POST["cf7_recrmio_email"] : '';
		$properties['cf7_recrmio_phone']     = isset($_POST["cf7_recrmio_phone"]) ? $_POST["cf7_recrmio_phone"] : '';
		$properties['cf7_recrmio_description']     = isset($_POST["cf7_recrmio_description"]) ? $_POST["cf7_recrmio_description"] : '';
		$properties['cf7_recrmio_lead_name']     = isset($_POST["cf7_recrmio_lead_name"]) ? $_POST["cf7_recrmio_lead_name"] : '';
		$properties['cf7_recrmio_city']     = isset($_POST["cf7_recrmio_city"]) ? $_POST["cf7_recrmio_city"] : '';
		
		$properties['cf7_recrmio_lead_source']     = isset($_POST["cf7_recrmio_lead_source"]) ? $_POST["cf7_recrmio_lead_source"] : '';
		$properties['cf7_recrmio_lead_source_description']     = isset($_POST["cf7_recrmio_lead_source_description"]) ? $_POST["cf7_recrmio_lead_source_description"] : '';
		$properties['cf7_recrmio_lead_assigned_to']     = isset($_POST["cf7_recrmio_lead_assigned_to"]) ? $_POST["cf7_recrmio_lead_assigned_to"] : '';
		$properties['cf7_recrmio_lead_company']     = isset($_POST["cf7_recrmio_lead_company"]) ? $_POST["cf7_recrmio_lead_company"] : '';

		update_post_meta($form_id, 'cf7_recrmio_data', $properties);
	}

	public function requestFromLog($data, $response_data)
	{
		# code...
	}

	public function showResponseLog()
	{
		require_once plugin_dir_path(__FILE__) . 'partials/LogList.php';
		$this->log_obj = new Cf7_recrmio_Log_List();
	?>
		<div class="wrap">
			<h2> <?php echo __('Realestatecrm Webform Log', 'Cf7_recrmio') ?></h2>

			<div id="">
				<div id="post-body" class="metabox-holder columns-2">
					<div id="post-body-content">
						<div class="meta-box-sortables ui-sortable">
							<form method="post">
								<?php
								$this->log_obj->prepare_items();
								$this->log_obj->display(); ?>
							</form>
						</div>
					</div>
				</div>
				<br class="clear">
			</div>
		</div>
<?php
	}
}
