
<?php
if (!class_exists('WP_List_Table')) {
    require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class Cf7_recrmio_Log_List extends WP_List_Table
{
    /** Class constructor */
    public function __construct()
    {

        parent::__construct([
            'singular' => __('Log', 'Cf7_recrmio'),
            'plural' => __('Logs', 'Cf7_recrmio'),
            'ajax' => false

        ]);
    }

    public static function get_logs($per_page = 10, $page_number = 1)
    {

        global $wpdb;
        $table_lead = $wpdb->prefix . "cf7_recrmio_lead";
        $sql = "SELECT * FROM $table_lead";

        if (!empty($_REQUEST['orderby'])) {
            $sql .= ' ORDER BY ' . esc_sql($_REQUEST['orderby']);
            $sql .= !empty($_REQUEST['order']) ? ' ' . esc_sql($_REQUEST['order']) : ' ASC';
        }

        $sql .= " LIMIT $per_page";

        $sql .= ' OFFSET ' . ($page_number - 1) * $per_page;

        $result = $wpdb->get_results($sql, 'ARRAY_A');

        return $result;
    }

    public static function delete_log($id)
    {
        global $wpdb;
        $table_lead = $wpdb->prefix . "cf7_recrmio_lead";
        $wpdb->delete(
            $table_lead,
            ['ID' => $id],
            ['%d']
        );
    }

    public static function retry_log($id)
    {
        global $wpdb;
        $table_lead = $wpdb->prefix . "cf7_recrmio_lead";
        $sql = "SELECT * FROM $table_lead";
        $sql .= " WHERE  ID = $id ";
        $row = $wpdb->get_row($sql);
        $cf7_recrmio_data			= get_post_meta($row->form_id, 'cf7_recrmio_data', true);
        if ($cf7_recrmio_data['cf7_recrmio_enable'] == 'on') {
			$api_key =  get_option('cf7-recrmio_api_key');
			$request_data = [
				'api_key' => $api_key,
				'first_name' => $row->first_name ,
				'last_name' =>  $row->last_name ,
				'email' => $row->email,
				'phone' =>  $row->phone,
				'description' => $row->description,
				'name' =>  $row->name ,
                'addr_city' =>  $row->city ,
                'lead_company' =>  $row->lead_company_name ,
				'lead_source_id' => $row->lead_source_id,
				'lead_source_description' =>  $row->lead_source_description,
				'owned_by' => $row->owned_by
			];


			if ($cf7_recrmio_data['cf7_recrmio_creaet_contact'] == 'on') {
				$request_data['create_new_contact'] = 1;
			} else {
				$request_data['create_new_contact'] = 0;
			}

			$response = self::createLead($request_data);
            $request_data['form_id'] = $row->form_id;
            $request_data['id'] = $row->ID;
			self::updateLogRequest($request_data, $response);
		}

      
    }

    public static function createLead($data)
	{

		$wp_request_headers = array(
			'Content-Type' => 'application/json'
		);

		$url        = CF7_RECRMIO_API . '/webform/leads/create';
		$response = wp_remote_post(
			$url,
			array(
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => $wp_request_headers,
				'body'        => json_encode($data),
				'cookies'     => array()
			)
		);
      
		if (is_wp_error($response)) {
			$response = [
				'msg'	=> $response->get_error_message(),
				'status'	=> 0
			];

			return $response;
		}

		$response_body = json_decode($response['body']);
      
        if( isset($response_body->status) && $response_body->status === 500  ){
			$response_data = [
				'msg'	=> $response_body->message,
				'status'	=> 0
			];
			return $response_data;
		}else if (isset($response_body->errors) && !empty($response_body->errors)) {

			if (isset($response_body->message->message)) {
				$response_data = [
					'msg'	=> $response_body->message->message,
					'status'	=> 0
				];
			} else if (is_string($response_body->message)) {
				$response_data = [
					'msg'	=> $response_body->message,
					'status'	=> 0
				];
			} else {
				$response_data = [
					'msg'	=> $response_body,
					'status'	=> 0
				];
			}

			return $response_data;
		} else if( !is_object($response_body )){
			$response_data = [
				'msg'	=> 'Something went wrong.',
				'status'	=> 0
			];
			return $response_data;
		}else {
			$response_data = [
				'msg'	=> $response_body->message->message,
				'lead'	=> $response_body->data,
				'status'	=> 1
			];

			return $response_data;
		}
	}


    public static function updateLogRequest($request_data, $response_data)
    {
        global $wpdb;
        $table_lead = $wpdb->prefix . "cf7_recrmio_lead";

        $lead_uuid        = isset($response_data['lead'][0]->uuid) ? $response_data['lead'][0]->uuid : '';
        $contact_uuid    = isset($response_data['lead'][0]->contact->uuid) ? $response_data['lead'][0]->contact->uuid : '';
        $status         = $response_data['status'];
        $lead            = isset($response_data['lead'][0]) ? $response_data['lead'][0] : [];
        $lead_data         = json_encode($lead);

        $response_msg     = is_string($response_data['msg']) ?  $response_data['msg']  : '';
        $query = " UPDATE  $table_lead SET "
            . " `name`='" . $request_data['name'] . "', "
            . " `first_name`='" . $request_data['first_name'] . "', "
            . " `last_name`='" . $request_data['last_name'] . "', "
            . " `email`='" . $request_data['email'] . "', "
            . " `phone`='" . $request_data['phone'] . "', "
            . " `city`='" . $request_data['addr_city'] . "', "
            . " `description`='" . $request_data['description'] . "', "
            . " `lead_source_id`='" . $request_data['lead_source_id'] . "', "
            . " `lead_company_name`='" . $request_data['lead_company'] . "', "
            . " `lead_source_description`='" . $request_data['lead_source_description'] . "', "
            . " `owned_by`='" . $request_data['owned_by'] . "', "
            . " `lead_uuid`='" . $lead_uuid . "', "
            . " `contact_uuid`='" . $contact_uuid . "', "
            . " `lead_data`='" . $lead_data . "', "
            . " `response_msg`='" . $response_msg . "', "
            . " `status`='" . $status . "', "
            . " `created_at`='" . date('Y-m-d H:i:s', time()) . "' "
            . " WHERE id ='" . $request_data['id']  . "' ";
        $wpdb->query($query);
    }


    public static function record_count()
    {
        global $wpdb;
        $table_lead = $wpdb->prefix . "cf7_recrmio_lead";
        $sql = "SELECT COUNT(*) FROM $table_lead";

        return $wpdb->get_var($sql);
    }

    public function no_items()
    {
        _e('No customers avaliable.', 'Cf7_recrmio');
    }

    function column_name($item)
    {
        // create a nonce
        $delete_nonce = wp_create_nonce('Cf7_recrmio_delete_log');

        $title = '<strong>' . $item['name'] . '</strong>';

        $actions = [
            'delete' => sprintf('<a href="?page=%s&action=%s&cf7_recrmio_log=%s&_wpnonce=%s">Delete</a>', esc_attr($_REQUEST['page']), 'delete', absint($item['ID']), $delete_nonce)
        ];

        return $title . $this->row_actions($actions);
    }

    function column_lead_uuid($item)
    {
        $lead_url = CF7_RECRMIO_URL . '/leads/leads/';
        $title = '<strong>' . $item['lead_uuid'] . '</strong>';
        $actions = [
            'view' => sprintf('<a href="%s" target="_blank">View</a>', $lead_url . $item['lead_uuid'])
        ];
        if (isset($item['lead_uuid']) && $item['lead_uuid'] != '') {
            return $title . $this->row_actions($actions);
        } else {
            return '';
        }
    }

    function column_contact_uuid($item)
    {
        $lead_url = CF7_RECRMIO_URL . '/contacts/contacts/';
        $title = '<strong>' . $item['contact_uuid'] . '</strong>';
        $actions = [
            'view' => sprintf('<a href="%s" target="_blank">View</a>', $lead_url . $item['contact_uuid'])
        ];
        if (isset($item['contact_uuid']) && $item['contact_uuid'] != '') {
            return $title . $this->row_actions($actions);
        } else {
            return '';
        }
    }

    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'name':
            case 'first_name':
            case 'email':
            case 'phone':
            case 'status':
            case 'response_msg':
            case 'lead_uuid':
            case 'contact_uuid':
                return $item[$column_name];
            default:
                return print_r($item, true); //Show the whole array for troubleshooting purposes
        }
    }

    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="bulk-delete[]" value="%s" />',
            $item['ID']
        );
    }

    function column_data_name($item)
    {
        return  $item['first_name'] . ' ' . $item['last_name'];
    }

    function column_status($item)
    {
        if ($item['status'] == 1) {
            return 'Success';
        } else {
            $retry_nonce = wp_create_nonce('Cf7_recrmio_delete_log');
            $title = '<strong> Pending </strong>';
            $actions = [
                'retry' => sprintf('<a href="?page=%s&action=%s&cf7_recrmio_log=%s&_wpnonce=%s&paged=%s" >Retry</a>', esc_attr($_REQUEST['page']), 'retry', absint($item['ID']), $retry_nonce, isset($_REQUEST['paged']) ? $_REQUEST['paged'] : '')
            ];
            return $title . $this->row_actions($actions);
            //return 'Pending';
        }
    }

    function get_columns()
    {
        $columns = [
            'cb' => '<input type="checkbox" />',
            'name' => __('Lead Name', 'Cf7_recrmio'),
            'data_name' => __('Name', 'Cf7_recrmio'),
            'email' => __('Email', 'Cf7_recrmio'),
            'phone' => __('Phone', 'Cf7_recrmio'),
            'lead_uuid' => __('Lead id', 'Cf7_recrmio'),
            'contact_uuid' => __('Contact id', 'Cf7_recrmio'),
            'response_msg' => __('Response', 'Cf7_recrmio'),
            'status' => __('Status', 'Cf7_recrmio'),
        ];

        return $columns;
    }

    public function get_sortable_columns()
    {
        $sortable_columns = array(
            'name' => array('name', true),
        );

        return $sortable_columns;
    }

    public function get_bulk_actions()
    {
        $actions = [
            'bulk-delete' => 'Delete'
        ];

        return $actions;
    }

    public function prepare_items()
    {

        $this->_column_headers = [
            $this->get_columns(),
            [], // hidden columns
            $this->get_sortable_columns(),
            $this->get_primary_column_name(),
        ];

        /** Process bulk action */
        $this->process_bulk_action();

        $per_page = $this->get_items_per_page('logs_per_page', 10);
        $current_page = $this->get_pagenum();
        $total_items = self::record_count();

        $this->set_pagination_args([
            'total_items' => $total_items, //WE have to calculate the total number of items
            'per_page' => $per_page //WE have to determine how many items to show on a page
        ]);

        $this->items = self::get_logs($per_page, $current_page);
    }

    public function process_bulk_action()
    {
        // retry log
        if ('retry' === $this->current_action()) {
            self::retry_log(absint($_GET['cf7_recrmio_log']));
            $url = esc_url(add_query_arg(array('page' => 'cf7-recrmio-log','paged'=> 2), admin_url('admin.php')));
            wp_redirect($url);
            exit;
        }

        //Detect when a bulk action is being triggered...
        if ('delete' === $this->current_action()) {

            // In our file that handles the request, verify the nonce.
            $nonce = esc_attr($_REQUEST['_wpnonce']);

            if (!wp_verify_nonce($nonce, 'Cf7_recrmio_delete_log')) {
                die('Go get a life script kiddies');
            } else {
                self::delete_log(absint($_GET['cf7_recrmio_log']));
                $url = esc_url(add_query_arg(array('page' => 'cf7-recrmio-log'), admin_url('admin.php')));
                wp_redirect($url);
                exit;
            }
        }


        // If the delete bulk action is triggered
        if ((isset($_POST['action']) && $_POST['action'] == 'bulk-delete')
            || (isset($_POST['action2']) && $_POST['action2'] == 'bulk-delete')
        ) {

            $delete_ids = esc_sql($_POST['bulk-delete']);

            // loop over the array of record IDs and delete them
            foreach ($delete_ids as $id) {
                self::delete_log($id);
            }

            wp_redirect(esc_url(add_query_arg()));
            exit;
        }
    }
}
