<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://realestatecrm.io
 * @since      1.0.0
 *
 * @package    Cf7_recrmio
 * @subpackage Cf7_recrmio/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Cf7_recrmio
 * @subpackage Cf7_recrmio/public
 * @author     Your Name <email@realestatecrm.io>
 */
class Cf7_recrmio_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $cf7_recrmio    The ID of this plugin.
	 */
	private $cf7_recrmio;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $cf7_recrmio       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($cf7_recrmio, $version)
	{

		$this->cf7_recrmio = $cf7_recrmio;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cf7_recrmio_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cf7_recrmio_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->cf7_recrmio, plugin_dir_url(__FILE__) . 'css/cf7-recrmio-public.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cf7_recrmio_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cf7_recrmio_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->cf7_recrmio, plugin_dir_url(__FILE__) . 'js/cf7-recrmio-public.js', array('jquery'), $this->version, false);
	}

	public function createDataFromWbForm($WPCF7_ContactForm)
	{
		$form_id = $WPCF7_ContactForm->id();
		$submission = WPCF7_Submission::get_instance();
		if ($submission) {
			$posted_data = $submission->get_posted_data();
		}
		$cf7_recrmio_data			= get_post_meta($form_id, 'cf7_recrmio_data', true);


		if ($cf7_recrmio_data['cf7_recrmio_enable'] == 'on') {
			$api_key =  get_option('cf7-recrmio_api_key');
			$request_data = [
				'api_key' => $api_key,
				'first_name' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_first_name']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_first_name']] : '',
				'last_name' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_last_name']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_last_name']] : '',
				'email' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_email']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_email']] : '',
				'phone' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_phone']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_phone']] : '',
				'description' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_description']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_description']] : '',

				'name' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_lead_name']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_lead_name']] : '',
				'lead_company' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_lead_company']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_lead_company']] : '',
				'lead_source_id' => isset($cf7_recrmio_data['cf7_recrmio_lead_source']) ? $cf7_recrmio_data['cf7_recrmio_lead_source'] : '',
				'lead_source_description' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_lead_source_description']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_lead_source_description']] : '',
				'owned_by' => isset($cf7_recrmio_data['cf7_recrmio_lead_assigned_to']) ? $cf7_recrmio_data['cf7_recrmio_lead_assigned_to'] : '',
				'addr_city' => isset($posted_data[$cf7_recrmio_data['cf7_recrmio_city']]) ? $posted_data[$cf7_recrmio_data['cf7_recrmio_city']] : '',
				
			];


			if ($cf7_recrmio_data['cf7_recrmio_creaet_contact'] == 'on') {
				$request_data['create_new_contact'] = 1;
			} else {
				$request_data['create_new_contact'] = 0;
			}

			$response = $this->createLead($request_data);
			$request_data['form_id'] = $form_id;
			$this->logRequest($request_data, $response);
		}
	}

	public function createLead($data)
	{

		$wp_request_headers = array(
			'Content-Type' => 'application/json'
		);

		$url        = CF7_RECRMIO_API . '/webform/leads/create';
		$response = wp_remote_post(
			$url,
			array(
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => $wp_request_headers,
				'body'        => json_encode($data),
				'cookies'     => array()
			)
		);

		if (is_wp_error($response)) {
			$response = [
				'msg'	=> $response->get_error_message(),
				'status'	=> 0
			];

			return $response;
		}

		$response_body = json_decode($response['body']);
		
		if( isset($response_body->status) && $response_body->status === 500  ){
			$response_data = [
				'msg'	=> $response_body->message,
				'status'	=> 0
			];
			return $response_data;
		}else if (isset($response_body->errors) && !empty($response_body->errors)) {

			if (isset($response_body->message->message)) {
				$response_data = [
					'msg'	=> $response_body->message->message,
					'status'	=> 0
				];
			} else if (is_string($response_body->message)) {
				$response_data = [
					'msg'	=> $response_body->message,
					'status'	=> 0
				];
			} else {
				$response_data = [
					'msg'	=> 'Something went wrong.',
					'status'	=> 0
				];
			}

			return $response_data;
		} else if( !is_object($response_body )){
			$response_data = [
				'msg'	=> 'Something went wrong.',
				'status'	=> 0
			];
			return $response_data;
		}else {
			$response_data = [
				'msg'	=> $response_body->message->message,
				'lead'	=> $response_body->data,
				'status'	=> 1
			];
			return $response_data;
		}
	}


	public function logRequest($request_data, $response_data)
	{
		global $wpdb;
		$table_lead = $wpdb->prefix . "cf7_recrmio_lead";

		$lead_uuid		= isset($response_data['lead'][0]->uuid) ? $response_data['lead'][0]->uuid : '';
		$contact_uuid	= isset($response_data['lead'][0]->contact->uuid) ? $response_data['lead'][0]->contact->uuid : '';
		$status 		= $response_data['status'];
		$lead			= isset($response_data['lead'][0] ) ? $response_data['lead'][0] : [];
		$lead_data 		= json_encode($lead);

		$response_msg 	= is_string($response_data['msg']) ?  $response_data['msg']  : '';
		$query = " INSERT INTO $table_lead SET "
			. " `name`='" . $request_data['name'] . "', "
			. " `first_name`='" . $request_data['first_name'] . "', "
			. " `last_name`='" . $request_data['last_name'] . "', "
			. " `email`='" . $request_data['email'] . "', "
			. " `phone`='" . $request_data['phone'] . "', "
			. " `city`='" . $request_data['addr_city'] . "', "
			. " `description`='" . $request_data['description'] . "', "
			. " `lead_company_name`='" . $request_data['lead_company'] . "', "
			. " `lead_source_id`='" . $request_data['lead_source_id'] . "', "
			. " `lead_source_description`='" . $request_data['lead_source_description'] . "', "
			. " `owned_by`='" . $request_data['owned_by'] . "', "
			. " `lead_uuid`='" . $lead_uuid . "', "
			. " `contact_uuid`='" . $contact_uuid . "', "
			. " `lead_data`='" . $lead_data . "', "
			. " `response_msg`='" . $response_msg . "', "
			. " `status`='" . $status . "', "
			. " `form_id`='" . $request_data['form_id'] . "', "
			. " `created_at`='" . date('Y-m-d H:i:s', time()) . "' ";
		$wpdb->query($query);
	}
}
